@@ -2,22 +2,20 @@ package SyForm::Exception::UnexpectedCallToGetValueByArgs;
 BEGIN {
   $SyForm::Exception::UnexpectedCallToGetValueByArgs::AUTHORITY = 'cpan:GETTY';
 }
-$SyForm::Exception::UnexpectedCallToGetValueByArgs::VERSION = '0.002';
+$SyForm::Exception::UnexpectedCallToGetValueByArgs::VERSION = '0.003';
 use Moose;
-extends 'Throwable::Error';
-use namespace::autoclean;
+extends 'SyForm::Exception';
 
 with qw(
   SyForm::Exception::Role::WithSyFormField
 );
 
-around throw => sub {
-  my ( $orig, $self, $field ) = @_;
-  $self->$orig({
-    message => '[ERROR] Unexpected call to get_value_by_args on the field "'.$field->name.'".'."\n\n".
-      ' There must be a call to has_value_by_args before using this function, to assure there exist a value.',
+sub throw_with_args {
+  my ( $class, $field ) = @_;
+  $class->throw('Unexpected call to get_value_by_args on the field ('.
+    $field->name.'). There must be a call to has_value_by_args before using this function, to assure there exist a value.',
     field => $field,
-  });
+  );
 };
 
 1;
@@ -32,7 +30,7 @@ SyForm::Exception::UnexpectedCallToGetValueByArgs
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 AUTHOR
 
