@@ -2,10 +2,9 @@ package SyForm::Exception::UnknownErrorOnCreate;
 BEGIN {
   $SyForm::Exception::UnknownErrorOnCreate::AUTHORITY = 'cpan:GETTY';
 }
-$SyForm::Exception::UnknownErrorOnCreate::VERSION = '0.002';
+$SyForm::Exception::UnknownErrorOnCreate::VERSION = '0.003';
 use Moose;
-extends 'Throwable::Error';
-use namespace::autoclean;
+extends 'SyForm::Exception';
 
 with qw(
   SyForm::Exception::Role::WithOriginalError
@@ -17,15 +16,14 @@ has create_args => (
   required => 1,
 );
 
-around throw => sub {
-  my ( $orig, $self, $create_args, $error ) = @_;
-  $self->$orig({
-    message => '[ERROR] Unknown error on create of SyForm'."\n\n".
-      ' Original error message:'."\n\n".$error,
+sub throw_with_args {
+  my ( $class, $create_args, $error ) = @_;
+  $class->rethrow_syform_exception($error);
+  $class->throw($class->error_message_text($error).' on create',
     create_args => $create_args,
     original_error => $error,
-  });
-};
+  );
+}
 
 1;
 
@@ -39,7 +37,7 @@ SyForm::Exception::UnknownErrorOnCreate
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 AUTHOR
 
