@@ -2,10 +2,9 @@ package SyForm::Exception::UnknownErrorOnProcess;
 BEGIN {
   $SyForm::Exception::UnknownErrorOnProcess::AUTHORITY = 'cpan:GETTY';
 }
-$SyForm::Exception::UnknownErrorOnProcess::VERSION = '0.002';
+$SyForm::Exception::UnknownErrorOnProcess::VERSION = '0.003';
 use Moose;
-extends 'Throwable::Error';
-use namespace::autoclean;
+extends 'SyForm::Exception';
 
 with qw(
   SyForm::Exception::Role::WithSyForm
@@ -18,15 +17,14 @@ has process_args => (
   required => 1,
 );
 
-around throw => sub {
-  my ( $orig, $self, $syform, $process_args, $error ) = @_;
-  $self->$orig({
-    message => '[ERROR] Unknown error on process of SyForm'."\n\n".
-      ' Original error message:'."\n\n".$error,
+sub throw_with_args {
+  my ( $class, $syform, $process_args, $error ) = @_;
+  $class->rethrow_syform_exception($error);
+  $class->throw($class->error_message_text($error).' on process',
     syform => $syform,
     original_error => $error,
     process_args => $process_args,
-  });
+  );
 };
 
 1;
@@ -41,7 +39,7 @@ SyForm::Exception::UnknownErrorOnProcess
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 AUTHOR
 
