@@ -2,23 +2,26 @@ package SyForm::Fields;
 BEGIN {
   $SyForm::Fields::AUTHORITY = 'cpan:GETTY';
 }
-$SyForm::Fields::VERSION = '0.002';
+$SyForm::Fields::VERSION = '0.003';
 use Moose::Role;
 use namespace::autoclean;
 
 sub as_hashref {
   my ( $self ) = @_;
   my %hashref;
-  for my $meta_attribute ($self->meta->get_all_attributes) {
-    if ($meta_attribute->does('SyForm::Meta::Attribute::Field')) {
-      my $name = $meta_attribute->name;
-      my $has = 'has_'.$name;
-      $hashref{$name} = $self->$name if $self->$has;
-    }
+  for my $name (@{$self->field_names}) {
+    my $has = 'has_'.$name;
+    $hashref{$name} = $self->$name if $self->$has;
   }
   return { %hashref };
 }
 
+has field_names => (
+  is => 'ro',
+  isa => 'ArrayRef[Str]',
+  required => 1,
+);
+
 1;
 
 __END__
@@ -31,7 +34,7 @@ SyForm::Fields
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 AUTHOR
 
